/**
 * GMyth Library
 *
 * @file gmyth/gmyth_tvplayer.h
 * 
 * @brief <p> This component provides playback of the remote A/V using
 * GStreamer.
 * 
 * Copyright (C) 2006 INdT - Instituto Nokia de Tecnologia.
 * @author Hallyson Luiz de Morais Melo <hallyson.melo@indt.org.br>
 *
 *//*
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#ifndef GMYTH_TVPLAYER_H_
#define GMYTH_TVPLAYER_H_

#include <glib-object.h>
#include <gtk/gtk.h>

/* GStreamer includes */
#include <gst/gst.h>
#include <gst/interfaces/xoverlay.h>

#include "gmyth_remote_encoder.h"
#include "gmyth_tvchain.h"
#include "gmyth_common.h"

G_BEGIN_DECLS

#define GMYTH_TVPLAYER_TYPE               (gmyth_tvplayer_get_type ())
#define GMYTH_TVPLAYER(obj)               (G_TYPE_CHECK_INSTANCE_CAST ((obj), GMYTH_TVPLAYER_TYPE, GMythTVPlayer))
#define GMYTH_TVPLAYER_CLASS(klass)       (G_TYPE_CHECK_CLASS_CAST ((klass), GMYTH_TVPLAYER_TYPE, GMythTVPlayerClass))
#define IS_GMYTH_TVPLAYER(obj)            (G_TYPE_CHECK_INSTANCE_CAST ((obj), GMYTH_TVPLAYER_TYPE))
#define IS_GMYTH_TVPLAYER_CLASS(klass)    (G_TYPE_CHECK_CLASS_CAST ((klass), GMYTH_TVPLAYER_TYPE))
#define GMYTH_TVPLAYER_GET_CLASS(obj)     (G_TYPE_INSTANCE_GET_CLASS ((obj), GMYTH_TVPLAYER_TYPE, GMythTVPlayerClass))


typedef struct _GMythTVPlayer         GMythTVPlayer;
typedef struct _GMythTVPlayerClass    GMythTVPlayerClass;

struct _GMythTVPlayerClass
{
    GObjectClass parent_class;

      /* callbacks */
      /*  no one for now */
};

struct _GMythTVPlayer
{
    GObject parent;
    
    GstElement *gst_pipeline;
    GstElement *gst_source;
    GstElement *gst_videodec;
    GstElement *gst_videosink;
    GstElement *videoqueue;
    GstElement *audioqueue;
    
    gulong expose_handler;
//    GMainLoop *loop;
    
    GtkWidget *videow;

	/* Backend connection related variables */
	GString *backend_hostname;
	gint backend_port;
	GString *local_hostname;

	GMythRemoteEncoder *remote_encoder;
	GMythTVChain *tvchain;
	GMythProgramInfo *proginfo;
	
	gboolean is_livetv;
};


GType          gmyth_tvplayer_get_type (void);

GMythTVPlayer* gmyth_tvplayer_new ();
gboolean       gmyth_tvplayer_initialize (GMythTVPlayer *tvplayer);

void           gmyth_tvplayer_start_playing   (GMythTVPlayer *tvplayer);
void           gmyth_tvplayer_stop_playing    (GMythTVPlayer *tvplayer);

gboolean       gmyth_tvplayer_set_widget   (GMythTVPlayer *tvplayer, 
                                            GtkWidget *videow);

gboolean       gmyth_tvplayer_is_playing   (GMythTVPlayer *tvplayer);

gboolean       gmyth_tvplayer_record_setup (GMythTVPlayer *tvplayer, 
                                            gchar *filename);
gboolean       gmyth_tvplayer_livetv_setup (GMythTVPlayer *tvplayer);

G_END_DECLS

#endif /*GMYTH_TVPLAYER_H_*/
